.. mdinclude:: ../README.md

.. toctree::
   :hidden:
   :maxdepth: 1

   pages/introduction.md
   auto_examples/index
   pages/api_references.rst

.. toctree::
   :hidden:
   :caption: Development

   pages/contributing.md
   GitHub repository <https://github.com/alexisthual/fugw>
